AutoImpute is developed and maintained by Joseph Kearney and Shahid Barkat.

Contacting the Authors
```````````````````````
- Joseph Kearney <josephkearney14@gmail.com> `@kearnz <https://github.com/kearnz>`
- Shahid Barkat <shahidbarkat@gmail.com> `@shabarka <https://github.com/shabarka>`
- Arnab Bose <bosearnab@gmail.com> `@bosearnab <https://github.com/bosearnab>`

